@@ -1,4 +1,6 @@
-#[derive(Debug, Clone)]
+use std::collections::HashMap;
+
+#[derive(Debug, Clone, PartialEq)]
 pub enum Token {
     Value(f64),
     Function(fn(WTokens) -> WTokens),
@@ -8,7 +10,7 @@ pub enum Token {
     Parameter(FunctionParameter),
     Atom(String),
     Special(String),
-    Group(Vec<Token>)
+    Group(Vec<Token>),
 }
 
 #[derive(Debug, Clone, Eq, PartialEq)]
@@ -20,7 +22,8 @@ pub enum FunctionParameter {
 #[derive(Debug, Clone)]
 pub struct WCode {
     pub container: Option<String>,
-    pub code: WTokens,
+    pub cases: Option<Vec<(WTokens, WTokens)>>,
+    pub default_case: WTokens,
 }
 
 #[derive(Debug, Clone)]
@@ -31,3 +34,4 @@ pub enum WFuncVariant {
 
 pub type WTokens = Vec<Token>;
 pub type WFunc = fn(WTokens) -> WTokens;
+pub type State = HashMap<String, Vec<(WTokens, WTokens)>>;
